Skip to contents

[Deprecated]

Calls a function provided by the user and adds the function call to the error message if the call fails.

Usage

call_user_fun(call)

Arguments

call

Call to be executed

Default value

none

Value

The return value of the function call