Convert a Date Character Vector into a Datetime Object
Source:R/derive_vars_dtm.R
convert_dtc_to_dtm.RdConvert a date character vector (usually --DTC) into a Date vector (usually *DTM).
Usage
convert_dtc_to_dtm(
dtc,
highest_imputation = "h",
date_imputation = "first",
time_imputation = "first",
min_dates = NULL,
max_dates = NULL,
preserve = FALSE
)Arguments
- dtc
-
The
--DTCdate to convert.- Permitted values
a character date vector
- Default value
none
- highest_imputation
-
Highest imputation level
The
highest_imputationargument controls which components of the--DTCvalue are imputed if they are missing. All components up to the specified level are imputed.If a component at a higher level than the highest imputation level is missing,
NAis returned. For example, forhighest_imputation = "D""2020"results inNAbecause the month is missing.If
"n"is specified, no imputation is performed, i.e., if any component is missing,NAis returned.If
"Y"is specified,date_imputationshould be"first"or"last"andmin_datesormax_datesshould be specified respectively. Otherwise,NAis returned if the year component is missing.- Permitted values
"Y"(year, highest level),"M"(month),"D"(day),"h"(hour),"m"(minute),"s"(second),"n"(none, lowest level)- Default value
"h"
- date_imputation
-
The value to impute the day/month when a datepart is missing.
A character value is expected.
The
"first"and"last"keywords allow imputation to the first/last day/month. They can also be used to impute the year if used in conjunction with themin_datesormax_datesarguments. Some examples of this are available here.-
When
highest_imputationis"M"or"D", the"mid"keyword can also be specified to impute missing components to the middle of the possible range:If both month and day are missing, they are imputed as
"06-30"(middle of the year).If only day is missing, it is imputed as
"15"(middle of the month).
"<dd>"can be specified only ifhighest_imputation = "D". Missing days are imputed by the specified day, e.g."10"for the 10th day of the month. The specified day should be valid for all months as otherwise an error might be issued. For example,date_imputation = "30"results in an invalid date of "2024-02-30" for the partial date "2024-02"."<mm>-<dd>"can be specified only ifhighest_imputationis"M", e.g."06-15"for the 15th of June.
- Permitted values
a key-word, i.e.
"first","mid","last", or"<mm>-<dd>"or"<dd>"- Default value
"first"
- time_imputation
-
The value to impute the time when a timepart is missing.
A character value is expected, either as a
format with hour, min and sec specified as
"hh:mm:ss": e.g."00:00:00"for the start of the day,or as a keyword:
"first","last"to impute to the start/end of a day.
The argument is ignored if
highest_imputation = "n".- Permitted values
"first","last", or user-defined- Default value
"first"
- min_dates
-
Minimum dates
A list of dates is expected. It is ensured that the imputed date is not before any of the specified dates, e.g., that the imputed adverse event start date is not before the first treatment date. Only dates which are in the range of possible dates of the
dtcvalue are considered. The possible dates are defined by the missing parts of thedtcdate (see example below). This ensures that the non-missing parts of thedtcdate are not changed. A date or date-time object is expected. For exampleimpute_dtc_dtm( "2020-11", min_dates = list( ymd_hm("2020-12-06T12:12"), ymd_hm("2020-11-11T11:11") ), highest_imputation = "M" )returns
"2020-11-11T11:11:11"because the possible dates for"2020-11"range from"2020-11-01T00:00:00"to"2020-11-30T23:59:59". Therefore"2020-12-06T12:12:12"is ignored. Returning"2020-12-06T12:12:12"would have changed the month although it is not missing (in thedtcdate).For date variables (not datetime) in the list the time is imputed to
"00:00:00". Specifying date variables makes sense only if the date is imputed. If only time is imputed, date variables do not affect the result.- Permitted values
a list of dates, e.g.
list(ymd_hms("2021-07-01T04:03:01"), ymd_hms("2022-05-12T13:57:23"))- Default value
NULL
- max_dates
-
Maximum dates
A list of dates is expected. It is ensured that the imputed date is not after any of the specified dates, e.g., that the imputed date is not after the data cut off date. Only dates which are in the range of possible dates are considered. A date or date-time object is expected.
For date variables (not datetime) in the list the time is imputed to
"23:59:59". Specifying date variables makes sense only if the date is imputed. If only time is imputed, date variables do not affect the result.- Permitted values
a list of dates, e.g.
list(ymd_hms("2021-07-01T04:03:01"), ymd_hms("2022-05-12T13:57:23"))- Default value
NULL
- preserve
-
Preserve lower level date/time part when higher order part is missing, e.g. preserve day if month is missing or preserve minute when hour is missing.
For example
"2019---07"would return"2019-06-07ifpreserve = TRUE(anddate_imputation = "mid").- Permitted values
TRUE,FALSE- Default value
FALSE
Details
This is a vector-oriented helper and is not usually called directly on a data
frame with %>%.
See also
Date/Time Computation Functions that returns a vector:
compute_age_years(),
compute_dtf(),
compute_duration(),
compute_tmf(),
convert_date_to_dtm(),
convert_dtc_to_dt(),
convert_xxtpt_to_hours(),
impute_dtc_dt(),
impute_dtc_dtm()