R/call_user_fun.R
call_user_fun.Rd
Calls a function provided by the user and adds the function call to the error message if the call fails.
call_user_fun(call)
Call to be executed
none
The return value of the function call
Other deprecated: date_source(), derive_param_extreme_record(), derive_var_dthcaus(), derive_var_extreme_dt(), derive_var_extreme_dtm(), derive_var_merged_summary(), dthcaus_source(), get_summary_records()
date_source()
derive_param_extreme_record()
derive_var_dthcaus()
derive_var_extreme_dt()
derive_var_extreme_dtm()
derive_var_merged_summary()
dthcaus_source()
get_summary_records()